@@ -1,8 +1,32 @@
+# $Id: $
+
+# Copyright (C) 2010-2013 Johannes Ranke
+# Contact: jranke@uni-bremen.de
+# The summary function is an adapted and extended version of summary.modFit
+# from the FME package, v 1.1 by Soetart and Petzoldt, which was in turn
+# inspired by summary.nls.lm
+
+# This file is part of the R package mkin
+
+# mkin is free software: you can redistribute it and/or modify it under the
+# terms of the GNU General Public License as published by the Free Software
+# Foundation, either version 3 of the License, or (at your option) any later
+# version.
+
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+# details.
+
+# You should have received a copy of the GNU General Public License along with
+# this program. If not, see <http://www.gnu.org/licenses/>
+utils::globalVariables(c("type", "variable", "observed"))
 plot.mkinfit <- function(x, fit = x,
   xlab = "Time", ylab = "Observed",
   xlim = range(fit$data$time), ylim = c(0, max(fit$data$observed, na.rm = TRUE)),
   col_obs = 1:length(fit$mkinmod$map),
-  pch_obs = col_obs, lty_obs = 1,
+  pch_obs = col_obs, 
+  lty_obs = rep(1, length(fit$mkinmod$map)),
   add = FALSE, legend = !add, ...)
 {
   solution_type = fit$solution_type
